@@ -43,10 +43,10 @@
 # define C_INSTALL_RC_COMPILER ""
 #endif
 #ifndef C_INSTALL_CFLAGS
-# define C_INSTALL_CFLAGS "-fno-strict-aliasing -fwrapv -DHAVE_CHICKEN_CONFIG_H -Wl,--as-needed -ffat-lto-objects -march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection         -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -g -ffile-prefix-map=/build/chicken/src=/usr/src/debug/chicken -flto=auto -w -O3 -fomit-frame-pointer"
+# define C_INSTALL_CFLAGS "-fno-strict-aliasing -fwrapv -DHAVE_CHICKEN_CONFIG_H -Wl,--as-needed -ffat-lto-objects -march=x86-64-v3 -O3 -pipe -fno-plt -fexceptions -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security -fstack-clash-protection -fcf-protection -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -mpclmul -g -ffile-prefix-map=/startdir/src=/usr/src/debug/chicken -flto=auto -falign-functions=32 -w -O3 -fomit-frame-pointer"
 #endif
 #ifndef C_INSTALL_LDFLAGS
-# define C_INSTALL_LDFLAGS "-Wl,--as-needed -Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro -Wl,-z,now          -Wl,-z,pack-relative-relocs -flto=auto "
+# define C_INSTALL_LDFLAGS "-Wl,--as-needed -Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro -Wl,-z,now          -Wl,-z,pack-relative-relocs -flto=auto -falign-functions=32 "
 #endif
 #ifndef C_INSTALL_PREFIX
 # define C_INSTALL_PREFIX "/usr"
@@ -103,13 +103,13 @@
 # define C_TARGET_INSTALL_PROGRAM "install"
 #endif
 #ifndef C_TARGET_CFLAGS
-# define C_TARGET_CFLAGS "-fno-strict-aliasing -fwrapv -DHAVE_CHICKEN_CONFIG_H -Wl,--as-needed -ffat-lto-objects -march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection         -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -g -ffile-prefix-map=/build/chicken/src=/usr/src/debug/chicken -flto=auto -w -O3 -fomit-frame-pointer"
+# define C_TARGET_CFLAGS "-fno-strict-aliasing -fwrapv -DHAVE_CHICKEN_CONFIG_H -Wl,--as-needed -ffat-lto-objects -march=x86-64-v3 -O3 -pipe -fno-plt -fexceptions -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security -fstack-clash-protection -fcf-protection -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -mpclmul -g -ffile-prefix-map=/startdir/src=/usr/src/debug/chicken -flto=auto -falign-functions=32 -w -O3 -fomit-frame-pointer"
 #endif
 #ifndef C_TARGET_LIBRARIAN_FLAGS
 # define C_TARGET_LIBRARIAN_FLAGS "cru"
 #endif
 #ifndef C_TARGET_LDFLAGS
-# define C_TARGET_LDFLAGS "-Wl,--as-needed -Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro -Wl,-z,now          -Wl,-z,pack-relative-relocs -flto=auto "
+# define C_TARGET_LDFLAGS "-Wl,--as-needed -Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro -Wl,-z,now          -Wl,-z,pack-relative-relocs -flto=auto -falign-functions=32 "
 #endif
 #ifndef C_TARGET_INSTALL_PROGRAM_EXECUTABLE_OPTIONS
 # define C_TARGET_INSTALL_PROGRAM_EXECUTABLE_OPTIONS "-m 755"
